"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BudBabelExtension = void 0;
const bud_build_1 = require("@roots/bud-build");
const fs_extra_1 = require("fs-extra");
const _1 = require(".");
const BudBabelExtension = {
    name: '@roots/bud-babel',
    register(app) {
        /**
         * Bind app.babel
         */
        app.extensions.bindClass({
            babel: [_1.Config, app],
        });
        /**
         * Register Build Loader
         */
        app.build.loaders.babel = new bud_build_1.Loader(require.resolve('babel-loader'));
        /**
         * Register Build Item
         */
        app.build.items.babel = new bud_build_1.Item({
            loader: ({ build }) => build.loaders.babel,
            options: app => {
                const options = {
                    cacheDirectory: app.path('storage', 'cache', 'babel'),
                    root: app.path('src'),
                };
                if (app.babel?.presets) {
                    options.presets = Object.values(app.babel.presets);
                }
                if (app.babel?.plugins) {
                    options.plugins = Object.values(app.babel.plugins);
                }
                return options;
            },
        });
        /**
         * Override Build JS Rule
         */
        app.build.rules.js.setUse(({ build }) => [build.items.babel]);
    },
    /**
     * Extension boot event
     */
    boot(app) {
        !fs_extra_1.existsSync(app.path('project', 'babel.config.js')) &&
            app.babel
                .setPresets(_1.DEFAULT_PRESETS)
                .setPlugins(_1.DEFAULT_PLUGINS);
    },
};
exports.BudBabelExtension = BudBabelExtension;
//# sourceMappingURL=BudBabelExtension.js.map