import { Item, Loader } from '@roots/bud-build';
import { existsSync } from 'fs-extra';
import { Config, DEFAULT_PLUGINS, DEFAULT_PRESETS } from '.';
const BudBabelExtension = {
    name: '@roots/bud-babel',
    register(app) {
        /**
         * Bind app.babel
         */
        app.extensions.bindClass({
            babel: [Config, app],
        });
        /**
         * Register Build Loader
         */
        app.build.loaders.babel = new Loader(require.resolve('babel-loader'));
        /**
         * Register Build Item
         */
        app.build.items.babel = new Item({
            loader: ({ build }) => build.loaders.babel,
            options: app => {
                const options = {
                    cacheDirectory: app.path('storage', 'cache', 'babel'),
                    root: app.path('src'),
                };
                if (app.babel?.presets) {
                    options.presets = Object.values(app.babel.presets);
                }
                if (app.babel?.plugins) {
                    options.plugins = Object.values(app.babel.plugins);
                }
                return options;
            },
        });
        /**
         * Override Build JS Rule
         */
        app.build.rules.js.setUse(({ build }) => [build.items.babel]);
    },
    /**
     * Extension boot event
     */
    boot(app) {
        !existsSync(app.path('project', 'babel.config.js')) &&
            app.babel
                .setPresets(DEFAULT_PRESETS)
                .setPlugins(DEFAULT_PLUGINS);
    },
};
export { BudBabelExtension };
//# sourceMappingURL=BudBabelExtension.js.map